=======
Testing
=======

There is a similar script for running tests::

    cd examples
    ./run_tests.sh vanilla
    
This specifies a sqlite3 database to use for testing and filters out the useless output.